@@ -5,7 +5,7 @@ use Data::Printer::Object;
 use Data::Printer::Common;
 use Data::Printer::Config;
 
-our $VERSION = '0.99_023';
+our $VERSION = '0.99_024';
 
 my $rc_arguments;
 my %arguments_for;
@@ -26,6 +26,8 @@ sub import {
             undef,
             'Data::Printer can receive either a hash or a hash reference'
         ) unless ref $args eq 'HASH';
+        $args = Data::Printer::Config::_expand_profile($args)
+            if exists $args->{profile};
     }
     $arguments_for{$caller} = $args;
 
@@ -66,10 +68,10 @@ sub np (\[@$%&];%) {
     }
     my $output = $printer->parse($_[0]);
     if ($printer->caller_message_position eq 'after') {
-        $output .= $printer->write_label;
+        $output .= $printer->_write_label;
     }
     else {
-        $output = $printer->write_label . $output;
+        $output = $printer->_write_label . $output;
     }
     return $output;
 }
@@ -94,10 +96,10 @@ sub p (\[@$%&];%) {
     }
     my $output = $printer->parse($_[0]);
     if ($printer->caller_message_position eq 'after') {
-        $output .= $printer->write_label;
+        $output .= $printer->_write_label;
     }
     else {
-        $output = $printer->write_label . $output;
+        $output = $printer->_write_label . $output;
     }
 
     return _handle_output($printer, $output, $want_value, $_[0]);
@@ -134,10 +136,10 @@ sub _p_without_prototypes  {
     }
     my $output = $printer->parse((defined $item ? $item : $_[0]));
     if ($printer->caller_message_position eq 'after') {
-        $output .= $printer->write_label;
+        $output .= $printer->_write_label;
     }
     else {
-        $output = $printer->write_label . $output;
+        $output = $printer->_write_label . $output;
     }
 
     return _handle_output($printer, $output, $want_value, $_[0]);
@@ -148,7 +150,7 @@ sub _handle_output {
     my ($printer, $output, $wantarray, $data) = @_;
 
     if ($printer->return_value eq 'pass') {
-        print { $printer->output_handle } $output . "\n";
+        print { $printer->{output_handle} } $output . "\n";
         require Scalar::Util;
         my $ref = Scalar::Util::blessed($data);
         return $data if defined $ref;
@@ -170,7 +172,7 @@ sub _handle_output {
         }
     }
     elsif ($printer->return_value eq 'void' || !$wantarray) {
-        print { $printer->output_handle } $output . "\n";
+        print { $printer->{output_handle} } $output . "\n";
         return;
     }
     else {
@@ -246,23 +248,21 @@ Want to see what's inside a variable in a complete, colored and human-friendly w
 
     use DDP;  # same as 'use Data::Printer'
 
-    my $var = SomeClass->new;  # or whatever
-
-    p $var;
-    p $var, as => "This label will be printed too!";
+    p $some_var;
+    p $some_var, as => "This label will be printed too!";
 
     # no need to use '\' before arrays or hashes!
     p @array;
     p %hash;
 
-    # for anonymous array/hash references, put '&' in front:
-    &p( [ $one, $two, $three ] );
-    &p( { foo => $foo, bar => $bar } );
-
-    # or use postderef on perl 5.24 or later:
+    # for anonymous array/hash references, use postderef (on perl 5.24 or later):
     p [ $one, $two, $three ]->@*;
     p { foo => $foo, bar => $bar }->%*;
 
+    # or put '&' in front of the call:
+    &p( [ $one, $two, $three ] );
+    &p( { foo => $foo, bar => $bar } );
+
 The snippets above will print the contents of the chosen variables to STDERR
 on your terminal, with colors and a few extra features to help you debug
 your code.
@@ -271,20 +271,21 @@ If you wish to grab the output and handle it yourself, call C<np()>:
 
     my $dump = np $var;
 
-    die "this is what happened: " . np(%data);
+    die "this is what happened: " . np %data;
 
 The C<np()> function is the same as C<p()> but will return the string
 containing the dump. By default it has no colors, but you can change that
 easily too.
 
+
 That's pretty much it :)
 
-Data::Printer is fully customizable. If you want to change how things are
-displayed, or even its standard behavior, just take a look at the
-L<available options|/Properties Quick Reference>. Once you figure out your
-own preferences, create a
+
+Data::Printer is L<fully customizable|/Properties Quick Reference>, even
+on a per-module basis! Once you figure out your own preferences, create a
 L<< .dataprinter configuration file|/The .dataprinter configuration file >>
-for yourself and Data::Printer will automatically use it!
+for yourself (or one for each project) and Data::Printer will automatically
+use it!
 
 =head1 FEATURES
 
@@ -307,18 +308,19 @@ You can even rename the exported C<p()> function!
 =over 4
 
 =item * B<< Beautiful (and customizable) colors >> to highlight variable dumps
-and make issues stand-out quickly on your console. Comes bundled with 4
-themes for you to pick that work on light and dark terminal backgrounds,
-and you can create your own as well.
+and make issues stand-out quickly on your console. Comes bundled with
+L<several themes|Data::Printer::Theme> for you to pick that work on light
+and dark terminal backgrounds, and you can create your own as well.
 
 =back
 
 =over 4
 
-=item * B<< Filters for specific data structures and objects >> to make
-debugging much, much easier. Includes filters for several popular classes
+=item * B<< L<Filters|/Filters> for specific data structures and objects >> to make
+debugging much, much easier. Includes filters for many popular classes
 from CPAN like JSON::\*, URI, HTTP::\*, LWP, Digest::\*, DBI and DBIx::Class.
-Also lets you create your own custom filters easily.
+printing what really matters to developers debugging code. It also lets you
+create your own custom filters easily.
 
 =back
 
@@ -335,16 +337,21 @@ or install hardcore tools like Devel::Peek and Devel::Gladiator.
 
 =over 4
 
-=item * B<< output to many different targets >> like files, variables or open
-handles (defaults to STDERR). You can send your dumps to the screen
-or anywhere else.
+=item * keep your custom settings on a
+L<< .dataprinter|/The .dataprinter configuration file >> file that allows
+B<< different options per module >> being analyzed! You may also create a
+custom L<profile|Data::Printer::Profile> class with your preferences and
+filters and upload it to CPAN.
 
 =back
 
 =over 4
 
-=item * keep your custom settings on a `.dataprinter` file that allows
-B<< different options per module >> being analyzed!
+=item * B<< output to many different targets >> like files, variables or open
+handles (defaults to STDERR). You can send your dumps to the screen
+or anywhere else, and customize this setting on a per-project or even
+per-module basis, like print everything from Some::Module to a debug.log
+file with extra info, and everything else to STDERR.
 
 =back
 
@@ -400,11 +407,11 @@ This function pretty-prints the contents of whatever variable to STDERR
     p %some_hash;
     p $scalar_or_ref;
 
-Note that anonymous structures will only work if you prefix C<p()> with C<&>.
-Parenthesis also becomes mandatory:
+Note that anonymous structures will only work if you either use postderef
+or prefix C<p()> with C<&>:
 
-    &p( [ $foo, $bar, $baz ] );
-    &p( { foo => $foo, bar => $bar } );
+    p [$foo, $bar, $baz]->@*;    # postderef
+    &p( [$foo, $bar, $baz] );    # & (note mandatory parenthesis)
 
 You can pass custom options that will work only on that particular call:
 
@@ -421,9 +428,9 @@ to this:
 
     sub foo { my $x = shift + 13; p($x) }
 
-The function will still return C<$x>. This form of handling data even allows
-method chaining, so if you want to inspect what's going on in the middle of
-this:
+The function will still return C<$x> after printing the contents. This form
+of handling data even allows method chaining, so if you want to inspect what's
+going on in the middle of this:
 
     $object->foo->bar->baz;
 
@@ -431,38 +438,39 @@ You can just add C<DDP::p> anywhere:
 
     $object->foo->DDP::p->bar->baz; # what happens to $object after ->foo?
 
-Check out the L<customization|/CUSTOMIZATION> section below for all available
-options so Data::Printer can show you exactly what you want, and output not
-just to STDERR but to files and much more.
+Check out the L<customization quick reference|/Properties Quick Reference>
+section below for all available options, including changing the return type,
+output target and a lot more.
 
 =head2 np()
 
 The C<np()> function behaves exactly like C<p()> except it always returns
 the string containing the dump (thus ignoring any setting regarding dump
-mode or destination), and contains no colors by default. It is meant to
-provide an easy way to fetch the dump and send it to some unsupported
-target, or appended to some other text (like part of a bigger message):
+mode or destination), and contains no colors by default. In fact, the only
+way to force a colored C<np()> is to pass C<< colored => 1 >> as an argument
+to each call. It is meant to provide an easy way to fetch the dump and send
+it to some unsupported target, or appended to some other text (like part of
+a log message).
 
 
 =head1 CUSTOMIZATION
 
-Passing arguments to C<p()> or C<np()> after the variable you are dumping
-lets you quickly override any global/local settings. The options are only
-used on that particular dump:
+There are 3 possible ways to customize Data::Printer:
 
-    p @var, colored => 0, show_refcount => 1;
-    p $var, as => 'this is my dump', show_memsize => 1;
+1. Creating a C<.dataprinter> file on your home directory, on your
+project's base directory or wherever you set the C<DATAPRINTERRC>
+environment variable to.
 
-Passing arguments to your Data::Printer/DDP call provides local settings to
-your current package. It lets you have different custom options that will be
-active on all calls to C<p()> and C<np()> on that package (unless they are
-overriden by passing arguments like shown above):
+2. Setting custom properties on module load. This will override any
+setting from (1) on the namespace (package/module) it was called:
 
-    package Foo;
     use DDP max_depth => 2, deparse => 1;
 
-    package main;
-    use DDP max_depth => 1, deparse => 0;
+3. Setting custom properties on the actual call to C<p()> or C<np()>. This
+overrides all other settings:
+
+    p $var, show_tainted => 1, indent => 2;
+
 
 =head2 The .dataprinter configuration file
 
@@ -487,101 +495,88 @@ is super simple and can be understood in the example below:
 
     [MyApp::Other::Module]
     multiline = 0
+    output    = /var/log/myapp/debug.data
 
-Note that on the C<.dataprinter> file you separate suboptions with C<.>, so
-"C<< class => { expand => 0, inherited => 'none' } >>" becomes
-"C<< class.expand = 0 >>" and "C<< class.inherited = none >>", each on their
-own line.
+Note that if you set custom properties as arguments to C<p()> or C<np()>, you
+should group suboptions as a hashref. So while the C<.dataprinter> file has
+"C<< class.expand = 0 >>" and "C<< class.inherited = none >>", the equivalent
+code is "C<< class => { expand => 0, inherited => 'none' } >>".
 
 =head2 Properties Quick Reference
 
-For a quick reference, below are all available properties and their
-(hopefully sane) default values. See L<Data::Printer::Object> for further
-information on each of them:
+Below are (almost) all available properties and their (hopefully sane)
+default values. See L<Data::Printer::Object> for further information on
+each of them:
 
     # scalar options
-    show_tainted      => 1,
-    show_unicode      => 1,
-    show_lvalue       => 1,
-    print_escapes     => 0,
-    scalar_quotes     => q("),
-    escape_chars      => 'none', # (nonascii, nonlatin1 all)
-    string_max        => 1024,
-    string_preserve   => 'begin', # (end, middle, extremes, none)
-    string_overflow   => '(...skipping __SKIPPED__ chars...)',
-    unicode_charnames => 0,
+    show_tainted      = 1
+    show_unicode      = 1
+    show_lvalue       = 1
+    print_escapes     = 0
+    scalar_quotes     = "
+    escape_chars      = none
+    string_max        = 4096
+    string_preserve   = begin
+    string_overflow   = '(...skipping __SKIPPED__ chars...)'
+    unicode_charnames = 0
 
     # array options
-    array_max      => 50,
-    array_preserve => 'begin', # end, middle, extremes, none
-    array_overflow => '(...skipping __SKIPPED__ items...)',
-    index          => 1,
+    array_max      = 100
+    array_preserve = begin
+    array_overflow = '(...skipping __SKIPPED__ items...)'
+    index          = 1
 
     # hash options
-    hash_max       => 50,
-    hash_preserve  => 'begin', # end, middle, extremes, none
-    hash_overflow  => '(...skipping __SKIPPED__ keys...)',
-    ignore_keys    => [],
-    hash_separator => '   ',
-    align_hash     => 1,
-    sort_keys      => 1,
-    quote_keys     => 'auto', # 0, 1
+    hash_max       = 100
+    hash_preserve  = begin
+    hash_overflow  = '(...skipping __SKIPPED__ keys...)'
+    hash_separator = '   '
+    align_hash     = 1
+    sort_keys      = 1
+    quote_keys     = auto
 
     # general options
-    name           => 'var', # the name to use for circular references
-    return_value   => 'pass', # also 'dump' and 'void'
-    output         => 'stderr', # stdout, \$string, $filehandle
-    use_prototypes => 1,
-    indent         => 4,
-    show_readonly  => 1,
-    show_tied      => 1,
-    show_dualvar   => 'lax', # strict, off
-    show_weak      => 1,
-    show_refcount  => 0,
-    show_memsize   => 0,
-    memsize_unit   => 'auto' # ('b', 'k', m)
-    separator      => ',',
-    end_separator  => 0,
-    caller_info    => 0,
-    caller_message => 'Printing in line __LINE__ of __FILENAME__',
-    max_depth      => 0,
-    deparse        => 0,
-    alias          => 'p',  # what to call p() when importing
-    warnings       => 1,    # show warnings if something goes wrong
+    name           = var
+    return_value   = pass
+    output         = stderr
+    use_prototypes = 1
+    indent         = 4
+    show_readonly  = 1
+    show_tied      = 1
+    show_dualvar   = lax
+    show_weak      = 1
+    show_refcount  = 0
+    show_memsize   = 0
+    memsize_unit   = auto
+    separator      = ,
+    end_separator  = 0
+    caller_info    = 0
+    caller_message = 'Printing in line __LINE__ of __FILENAME__'
+    max_depth      = 0
+    deparse        = 0
+    alias          = p
+    warnings       = 1
 
     # colorization (see Colors & Themes below)
-    colored => 'auto', # 0, 1
-    theme   => 'Material',
-    colors  => { ... },  # override theme colors
+    colored = auto
+    theme   = Material
 
     # object output
-    class_method => '_data_printer',
-    class => {
-        parents            => 1,
-        linear_isa         => 'auto',
-        universal          => 1,
-        expand             => 1,
-        stringify          => 1,
-        show_reftype       => 0,
-        show_overloads     => 1,
-        show_methods       => 'all', # none, public, private
-        sort_methods       => 1,
-        inherited          => 'none',   # all, public, private
-        format_inheritance => 'string', # lines
-        parent_filters     => 1,
-        internals          => 1,
-    },
+    class_method             = _data_printer
+    class.parents            = 1
+    class.linear_isa         = auto
+    class.universal          = 1
+    class.expand             = 1
+    class.stringify          = 1
+    class.show_reftype       = 0
+    class.show_overloads     = 1
+    class.show_methods       = all
+    class.sort_methods       = 1
+    class.inherited          = none
+    class.format_inheritance = string
+    class.parent_filters     = 1
+    class.internals          = 1
 
-    # filters (see Filters below)
-    filters => [
-        {
-            SCALAR    => sub { ... }, # <-- inline filter for SCALARs
-            SomeClass => sub { ... }, # <-- inline filter for class 'SomeClass'
-            -class    => sub { ... }. # <-- inline filter for all classes
-        },
-        'DB',  # <-- loads Data::Printer::Filter::DB
-        'Web', # <-- loads Data::Printer::Filter::Web
-    ],
 
 =head3 Settings shortcuts
 
@@ -606,46 +601,23 @@ which is trimmed by default.
 
 =back
 
+
 =head2 Colors & Themes
 
-Data::Printer's colorization is set via the C<colorize> output, which can be
-set to C<1> (always colorize), C<0> (never colorize) or C<'auto'>.
+Data::Printer lets you set custom colors for pretty much every part of the
+content being printed. For example, if you want numbers to be shown in
+bright green, just put C<< colors.number = #00ff00 >> on your configuration
+file.
 
-Data::Printer's default color mode is 'auto', meaning it will colorize
-the output only when all conditions below are met:
+See L<Data::Printer::Theme> for the full list of labels, ways to represent
+and customize colors, and even how to group them in your own custom theme.
 
-=over 4
+The colorization is set by the C<colored> property. It can be set to 0
+(never colorize), 1 (always colorize) or 'auto' (the default), which will
+colorize C<p()> only when there is no C<ANSI_COLORS_DISABLED> environment
+variable, the output is going to the terminal (STDOUT or STDERR) and your
+terminal actually supports colors.
 
-=item * There is no C<ANSI_COLORS_DISABLED> environment variable;
-
-=item * The output is going to the terminal, not just returned;
-
-=item * The output handle (STDERR by default) is not being piped;
-
-=item * Your terminal supports colors (most do nowadays).
-
-=back
-
-Data::Printer's colored output is handled by the C<colors> option. You may
-set each color individually, using ANSIColors naming, hex color tags or RGB:
-
-    use DDP colors => {
-        array  => 'blue',
-        number => '#2e4f0a',
-        undef  => 'rgb(255,80,103)',
-        # and many more!
-    },
-
-You may also use any of Data::Printer's available themes:
-
-    use DDP theme => 'Monokai';
-
-This will load Data::Printer::Theme::Monokai, that contains all color
-settings. You are encouraged to create your own themes and upload them
-to CPAN for others to use as well!
-
-See L<Data::Printer::Theme> for information on how to create your own custom
-theme, and for a complete list of all natively used color labels.
 
 =head2 Profiles
 
@@ -665,40 +637,35 @@ of available profiles and how to make one yourself.
 
 Data::Printer works by passing your variable to a different set of filters,
 depending on whether it's a scalar, a hash, an array, an object, etc. It
-comes bundled with filters for all native data types and several others for
-the most common objects on CPAN. To set your own filter, simply add it to the
-C<filters>. The list may receive named filters:
+comes bundled with filters for all native data types (always enabled, but
+overwritable), including a generic object filter that pretty-prints regular
+and Moo(se) objects and is even aware of Role::Tiny.
 
-    use DDP filters => [ 'DB', 'Web' ];
+Data::Printer also comes with filter bundles that can be quickly activated
+to make it easier to debug L<Data::Printer::Filter::ContentType|binary data>
+and many popular CPAN modules that handle
+L<Data::Printer::Filter::DateTime|date and time>,
+L<Data::Printer::Filter::DB|databases> (yes, even DBIx::Class),
+L<Data::Printer::Filter::Digest|message digests> like MD5 and SHA1, and
+L<Data::Printer::Filter::Web|JSON and Web> content like HTTP requests and responses.
 
-Which will load C<< <Data::Printer::Filter::DB >> and C<< ::Web >>,
-respectively. It may also get a hashref of inline filters:
+So much so we recommend everyone to activate all bundled filters by putting
+the following line on your C<.dataprinter> file:
 
-    use DDP filters => [{
-        SCALAR       => sub { ... },
-        'My::Module' => sub { ... },
-    }];
+    filters = ContentType, DateTime, DB, Digest, Web
 
-Or any combination of those. Creating your custom filters is very easy, and
+Creating your custom filters is very easy, and
 you're encouraged to upload them to CPAN. There are many options available
 under the C<< Data::Printer::Filter::* >> namespace. Check
-L<Data::Printer::Filter> for extra information!
+L<Data::Printer::Filter> for more information!
 
-While you may not put subrefs on your C<.dataprinter> file, you can load any
-external filters easily:
 
-    filters = DB, DateTime, Web
+=head2 Making your classes DDP-aware (without adding any dependencies!)
 
-=head1 MAKING YOUR CLASSES AWARE OF DDP (WITHOUT ADDING ANY DEPS)
-
-Whenever printing the contents of a class, Data::Printer first
-checks to see if that class implements a sub called 'C<_data_printer()>'
-(or whatever you set the "class_method" option to in your settings,
-see L</Properties Quick Reference>).
-
-If a sub with that exact name is available in the target object,
-Data::Printer will use it to get the string to print instead of
-making a regular class dump.
+The default object filter will first check if the class implements a sub
+called 'C<_data_printer()>' (or whatever you set the "class_method" option
+to in your settings). If so, Data::Printer will use it to get the string to
+print instead of making a regular class dump.
 
 This means you could have the following in one of your classes:
 
@@ -708,25 +675,24 @@ This means you could have the following in one of your classes:
   }
 
 Notice that B<< you can do this without adding Data::Printer as a dependency >>
-to your project! Just write your sub and it will use that to pretty-print
-your objects. The sub will be called with the object to be printed and also
-with a C<$ddp> object ready for you. See L<Data::Printer::Object> for
+to your project! Just write your sub and it will be called with the object to
+be printed and a C<$ddp> object ready for you. See L<Data::Printer::Object> for
 how to use it to pretty-print your data.
 
-Having a filter for that particular class will of course override this setting.
-
 Finally, if your object implements string overload or provides a method called
 "to_string", "as_string" or "stringify", Data::Printer will use it. To disable
 this behaviour, set C<< class.stringify = 0 >> on your C<.dataprinter>
 file, or call p() with C<< class => { stringify => 0 } >>.
 
+Loading a filter for that particular class will of course override these settings.
+
+
 =head1 CAVEATS
 
 You can't pass more than one variable at a time.
 
-   p($foo, $bar);  # wrong
-   p($foo);        # right
-   p($bar);        # right
+   p $foo, $bar;       # wrong
+   p $foo; p $bar;     # right
 
 You can't use it in variable declarations (it will most likely not do what
 you want):
@@ -734,18 +700,19 @@ you want):
     p my @array = qw(a b c d);          # wrong
     my @array = qw(a b c d); p @array;  # right
 
-On the default mode of C<< use_prototypes => 1 >>, you cannot pass anonymous
+On the default mode of C<< use_prototypes = 1 >>, you cannot pass anonymous
 data:
 
     p { foo => 1 };       # wrong!
-
-Try any of the forms below instead, or set C<use_prototypes> to 0:
-
-    p %{ { foo => 1 } };  # right
-    p { foo => 1 }->%*;   # also right on perl 5.24+
+    p %{{ foo => 1 }};    # right
+    p { foo => 1 }->%*;   # right on perl 5.24+
     &p( { foo => 1 } );   # right, but requires the parenthesis
+    sub pp { p @_ };      # wrapping it also lets you use anonymous data.
 
-Also, if you pass a nonexistant key/index to DDP using prototypes, they
+    use DDP use_prototypes => 0;
+    p { foo => 1 };   # works, but now you must always pass a reference to p()
+
+If you pass a nonexistant key/index to DDP using prototypes, they
 will trigger autovivification:
 
     use DDP;
@@ -802,89 +769,6 @@ please file an issue on Github!
 
 =head1 TIPS & TRICKS
 
-=head2 Circumventing prototypes
-
-The C<p()> function uses prototypes by default, allowing you to say:
-
-    p %var;
-
-instead of always having to pass references, like:
-
-    p \%var;
-
-There are cases, however, where you may want to pass anonymous
-structures, like:
-
-    p { foo => $bar };   # this blows up, don't use!
-
-and because of prototypes, you can't. If this is your case, just
-set "use_prototypes" option to 0. Note, with this option,
-you B<will> have to pass your variables as references:
-
-    use DDP use_prototypes => 0;
-
-    p { foo => 'bar' }; # doesn't blow up anymore, works just fine.
-
-    p %var;  # but now this blows up...
-    p \%var; # ...so do this instead!
-
-    p [ $foo, $bar, \@baz ]; # this way you can even pass
-                             # several variables at once
-
-If you want to keep using prototypes but still be able to call C<p()> with
-anonymous data, you may also try any of these formats:
-
-    &p( { foo => $bar } );        # this is ok, but requires the parentheses
-    &p( \"DEBUGGING THIS BIT" );  # this works too
-
-    p %{{ foo => $bar }};    # reref works in all versions of perl 5
-    p { foo => $bar }->%*;   # postderef works on 5.24 and newer perls
-
-Or you could just create a very simple wrapper function:
-
-  sub pp { p @_ };
-
-And use it as you use C<p()>.
-
-=head2 Minding the return value of p()
-
-I<< (contributed by Matt S. Trout (mst)) >>
-
-Since Data::Printer 0.36, the default return value changed from 'dump'
-to 'pass'. If you are using the 'dump' mode, the return value o p()
-is the serialized form of the dump (like np()) unless in void context, in
-which case it will print the string. While it's tempting to trust your own
-p() calls with that approach, if this is your I<last> statement in a function,
-you should keep in mind your debugging code will behave differently depending
-on how your function was called!
-
-To prevent that, set the C<return_value> property to either 'void' or 'pass'.
-You won't be able to retrieve the dumped string but, hey, who does that anyway
-:) Besides, you can use np() for that, too.
-
-Assuming you are using the default pass-through ('pass') property, another
-stunningly useful thing you can do with it is change code that says:
-
-   return $obj->foo;
-
-with:
-
-   use DDP;
-
-   return p $obj->foo;
-
-You can even add it to chained calls if you wish to see the dump of
-a particular state, changing this:
-
-   $obj->foo->bar->baz;
-
-to:
-
-   $obj->foo->DDP::p->bar->baz
-
-And things will "Just Work".
-
-
 =head2 Using p() in some/all of your loaded modules
 
 I<< (contributed by Matt S. Trout (mst)) >>
@@ -893,17 +777,18 @@ While debugging your software, you may want to use Data::Printer in some or
 all loaded modules and not bother having to load it in each and every one of
 them. To do this, in any module loaded by C<myapp.pl>, simply write:
 
-  ::p( @myvar );  # note the '::' in front of p()
+  ::p @myvar;  # note the '::' in front of p()
 
 Then call your program like:
 
   perl -MDDP myapp.pl
 
-This also has the great advantage that if you leave one p() call
-in by accident, it will fail without the -M, making it easier to spot :)
+This also has the advantage that if you leave one p() call in by accident,
+it will trigger a compile-time failure without the -M, making it easier to
+spot :)
 
-If you really want to have p() imported into your loaded
-modules, use the next tip instead.
+If you really want to have p() imported into your loaded modules, use the
+next tip instead.
 
 =head2 Adding p() to all your loaded modules
 
@@ -955,7 +840,7 @@ Now Data::Printer's C<p()> command will be used instead of the debugger's!
 See L<perldebug> for more information on how to use the perl debugger, and
 L<DB::Pluggable> for extra functionality and other plugins.
 
-If you can't or don't wish to use DB::Pluggable, or simply want to keep
+If you can't or don't want to use DB::Pluggable, or simply want to keep
 the debugger's C<p()> function and add an extended version using
 Data::Printer (let's call it C<px()> for instance), you can add these
 lines to your C<.perldb> file instead:
@@ -973,7 +858,7 @@ to be dumped using Data::Printer.
 =head2 Using Data::Printer in a perl shell (REPL)
 
 Some people really enjoy using a REPL shell to quickly try Perl code. One
-of the most famous ones out there is L<Devel::REPL>. If you use it, now
+of the most popular ones out there is L<Devel::REPL>. If you use it, now
 you can also see its output with Data::Printer!
 
 Just install L<Devel::REPL::Plugin::DataPrinter> and add the following
@@ -992,7 +877,7 @@ To turn Data::Printer's output into HTML, you can do something like:
   use HTML::FromANSI;
   use Data::Printer;
 
-  my $html_output = ansi2html( p($object, colored => 1) );
+  my $html_output = ansi2html( np($object, colored => 1) );
 
 In the example above, the C<$html_output> variable contains the
 HTML escaped output of C<p($object)>, so you can print it for
@@ -1031,7 +916,6 @@ Data::Dumper or similar, you can just replace:
 with:
 
   use Data::Printer alias => 'Dumper';
-  # use Data::Dumper;
 
 making sure to provide Data::Printer with the proper alias for the
 previous dumping function.
@@ -1069,10 +953,10 @@ data structures too!
 
    # Print a stack trace every time the name is changed,
    # except when reading from the database.
-   dip -e 'before { print longmess(p $_->{args}[1]) if $_->{args}[1] }
-     call "MyObj::name" & !cflow("MyObj::read")' myapp.pl
+   dip -e 'before { print longmess(np $_->{args}[1], colored => 1)
+   if $_->{args}[1] } call "MyObj::name" & !cflow("MyObj::read")' myapp.pl
 
-You can check you L<dip>'s own documentation for more information and options.
+You can check L<dip>'s own documentation for more information and options.
 
 =head2 Sample output for color fine-tuning
 
@@ -1081,43 +965,6 @@ I<< (contributed by Yanick Champoux (yanick)) >>
 The "examples/try_me.pl" file included in this distribution has a sample
 dump with a complex data structure to let you quickly test color schemes.
 
-=head2 creating fiddling filters
-
-I<< (contributed by dirk) >>
-
-Sometimes, you may want to take advantage of Data::Printer's original dump,
-but add/change some of the original data to enhance your debugging ability.
-Say, for example, you have an C<HTTP::Response> object you want to print
-but the content is encoded. The basic approach, of course, would be to
-just dump the decoded content:
-
-  use DDP filter {
-    'HTTP::Response' => sub { p( \shift->decoded_content, %{shift} );
-  };
-
-But what if you want to see the rest of the original object? Dumping it
-would be a no-go, because you would just recurse forever in your own filter.
-
-Never fear! When you create a filter in Data::Printer, you're not replacing
-the original one, you're just stacking yours on top of it. To forward your data
-to the original filter, all you have to do is return an undefined value. This
-means you can rewrite your C<HTTP::Response> filter like so, if you want:
-
-  use DDP filters => {
-    'HTTP::Response' => sub {
-      my ($res, $p) = @_;
-
-      # been here before? Switch to original handler
-      return if exists $res->{decoded_content};
-
-      # first timer? Come on in!
-      my $clone = $res->clone;
-      $clone->{decoded_content} = $clone->decoded_content;
-      return p($clone, %$p);
-    }
-  };
-
-And voilà! Your fiddling filter now works like a charm :)
 
 =head1 CONTRIBUTORS
 
@@ -1157,7 +1004,7 @@ If I missed your name, please drop me a line!
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2011-2018 Breno G. de Oliveira
+Copyright (C) 2011-2021 Breno G. de Oliveira
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
